@@ -1,3 +1,8 @@
+/*--- Chris S.: June 10, 1999   */
+/*---  reads in a generator type as an integer */
+/*---adding 'int gentype' and read in + error handling */
+/*--- generator numeral range is fix-set to 0-5 ?  */
+/*--- should 5 be change to some variable MAX_GEN_NUMBER ? */
 #include <stdio.h>
 #include <stdlib.h>
 #include "cputime.h"
@@ -8,13 +13,26 @@
 
 main()
 {
+
   int i;
   int *gen;
   double temp1, temp2, temp3, temp4;
   double temp_mult = TIMING_TRIAL_SIZE/1.0e6;
+/*---   */
+  int gentype;
   
-  gen = init_rng(0,1,0,PARAM);
-  /*print_rng(gen);*/
+  scanf("%d\n", &gentype);
+  if((gentype < 0) || (gentype > 5))  /*--- range to be adjusted if needed */
+  {
+    printf("\nGenerator numeral out of range.\n\t...Exiting\n");    
+    exit(1);
+  }
+/*---   */  
+
+
+  gen = init_rng(gentype,0,1,0,PARAM);
+/*--- Printing generator and stream information */
+/*  print_rng(gen); */
   
   temp1 = cputime();
 
